@@ -271,7 +271,7 @@ sub script {
             $file =~ s/ /\\ /g;
         }
         my $files_list = join(" ", @{$self_files});
-        my $list = "\$self_files=($files_list)";
+        my $list = "self_files=($files_list)";
         push(@prepend, "# Job array list", "$list", "selected_file=\${self_files[\$SLURM_ARRAY_TASK_ID]}");
         
         # Prepend the array to the commands
@@ -409,7 +409,7 @@ NBI::Job - A class for representing a job for NBI::Slurm
 
 =head1 VERSION
 
-version 0.9.0
+version 0.10.0
 
 =head1 DESCRIPTION
 
@@ -601,7 +601,7 @@ Andrea Telatin <proch@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by Andrea Telatin.
+This software is Copyright (c) 2023-2025 by Andrea Telatin.
 
 This is free software, licensed under:
 
